@@ -7,7 +7,7 @@ from quickboard.dashsetup import app
 from quickboard.utils.environment import isnotebook
 
 
-def start_app(board, host=os.getenv("HOST", "127.0.0.1"), port=8050, extra_stores=[]):
+def start_app(board, mode='external', host=os.getenv("HOST", "127.0.0.1"), port=8050, extra_stores=[]):
     """
     Takes an app instance and configures its board layout, then runs the app on given port. Use extra_stores for
     extra data stores.
@@ -20,11 +20,7 @@ def start_app(board, host=os.getenv("HOST", "127.0.0.1"), port=8050, extra_store
         dcc.Store(id=name, data={}) for name in extra_stores
     ])
 
-#    if __name__ == '__main__':
-#        app.run_server(debug=True, port=port)
     if isnotebook():
-        app.run_server(mode='external', debug=True, host=host, port=port)
+        app.run_server(mode=mode, debug=True, host=host, port=port)
     else:
         app.run_server(debug=True, host=host, port=port)
-#    else:
-#        print("ERROR: Improper environment for running Dash app.")
